Learn R Programming

capybara (version 1.0.1)

autoplot.feglm: Autoplot method for feglm objects

Description

Extracts the estimated coefficients and their confidence intervals.

Extracts the estimated coefficients and their confidence

Usage

# S3 method for feglm
autoplot(object, ...)

# S3 method for felm autoplot(object, ...)

Value

A ggplot object with the estimated coefficients and their confidence intervals.

A ggplot object with the estimated coefficients and their confidence intervals.

Arguments

object

A fitted model object.

...

Additional arguments passed to the method. In this case, the additional argument is conf_level, which is the confidence level for the confidence interval.

Examples

Run this code
mod <- fepoisson(mpg ~ wt + drat | cyl, mtcars)
autoplot(mod, conf_level = 0.99)

mod <- felm(mpg ~ wt + drat | cyl, mtcars)
autoplot(mod, conf_level = 0.90)

Run the code above in your browser using DataLab