correia2019: Separation Example Datasets

correia2019R Documentation

Separation Example Datasets

Description

Nonexistence of estimates of Poisson models across different statistical packages.

Usage

correia2019

Format

correia2019

A list of data frames with three elements:

example1

Data frame used to show lack of convergence

example2

Data frame used to show lack of convergence with step-halving

fe1

Data frame with fixed effects used with the 'alpaca' package

'correia2019' GitHub repository (https://github.com/sergiocorreia/correia2019/blob/master/guides/nonexistence_benchmarks.md#r-packages)


capybara documentation built on June 15, 2026, 9:10 a.m.