ross2004: Subset of WTO data from Ross (2004)

ross2004R Documentation

Subset of WTO data from Ross (2004)

Description

Data from Ross (2004) used to show the different variance-covariance estimators from Cameron and Miller (2014).

Usage

ross2004

Format

ross2004

A data frame with 234,597 rows and 22 columns:

ltrade

Log of bilateral trade between i and j at time t

bothin

Binary variable which is unity if both i and j are GATT/WTO members at t

onein

Binary variable which is unity if either i or j is a GATT/WTO member at t

gsp

Binary variable which is unity if i was a GSP beneficiary of j or vice versa at t

ldist

Log of distance between i and j

lrgdp

Log of real GDP

lrgdppc

Log of real GDP per capita

regional

Binary variable which is unity if i and j are in the same region

custrict

Binary variable which is unity if i and j are in the same customs union

comlang

Binary variable which is unity if i and j share a common language

border

Binary variable which is unity if i and j share a border

landl

Number of landlocked countries in the country-pair (0, 1, or 2)

island

Number of island nations in the pair (0, 1, or 2)

lareap

Log of the area of the country (in square kilometers)

comcol

Binary variable which is unity if i and j were ever colonies after 1945 with the same colonizer

curcol

Binary variable which is unity if i and j are colonies at time t

colony

Binary variable which is unity if i ever colonized j or vice versa

comctry

Binary variable which is unity if i and j remained part of the same nation during the sample (e.g., France and Guadeloupe)

ctry1

Country 1 ISO-3 code

ctry2

Country 2 ISO-3 code

pair

Country pair undirected dyads

year

Year of observation

Do We Really Know That the WTO Increases Trade? (DOI: 10.1257/000282804322970724)


capybara documentation built on June 15, 2026, 9:10 a.m.