| autoplot.feglm | R Documentation |
Extracts the estimated coefficients and their confidence intervals.
Extracts the estimated coefficients and their confidence intervals.
## S3 method for class 'feglm'
autoplot(object, ...)
## S3 method for class 'felm'
autoplot(object, ...)
object |
A fitted model object. |
... |
Additional arguments passed to the method. In this case, the additional argument is |
A ggplot object with the estimated coefficients and their confidence intervals.
A ggplot object with the estimated coefficients and their confidence intervals.
ross2004_subset <- ross2004[ross2004$year == 1999, ]
ross2004_subset <- ross2004_subset[ross2004_subset$ltrade >
quantile(ross2004_subset$ltrade, 0.75), ]
fit <- fepoisson(ltrade ~ ldist | ctry1, ross2004_subset)
autoplot(fit, conf_level = 0.99)
ross2004_subset <- ross2004[ross2004$year == 1999, ]
ross2004_subset <- ross2004_subset[ross2004_subset$ltrade >
quantile(ross2004_subset$ltrade, 0.75), ]
fit <- felm(ltrade ~ ldist | ctry1, ross2004_subset)
autoplot(fit, conf_level = 0.99)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.