| augment.feglm | R Documentation |
The provided broom methods do the following:
augment: Takes the input data and adds additional columns with the fitted values and residuals.
glance: Extracts the deviance, null deviance, and the number of observations.'
tidy: Extracts the estimated coefficients and their standard errors.
## S3 method for class 'feglm'
augment(x, newdata = NULL, ...)
## S3 method for class 'felm'
augment(x, newdata = NULL, ...)
## S3 method for class 'feglm'
glance(x, ...)
## S3 method for class 'felm'
glance(x, ...)
## S3 method for class 'feglm'
tidy(x, conf_int = FALSE, conf_level = 0.95, ...)
## S3 method for class 'felm'
tidy(x, conf_int = FALSE, conf_level = 0.95, ...)
x |
A fitted model object. |
newdata |
Optional argument to use data different from the data used to fit the model. |
... |
Additional arguments passed to the method. |
conf_int |
Logical indicating whether to include the confidence interval. |
conf_level |
The confidence level for the confidence interval. |
A tibble with the respective information for the augment, glance, and tidy methods.
ross2004_subset <- ross2004[ross2004$year == 1999, ]
ross2004_subset <- ross2004_subset[ross2004_subset$ltrade >
quantile(ross2004_subset$ltrade, 0.75), ]
fit <- fepoisson(ltrade ~ ldist, ross2004_subset,
control = fit_control(keep_data = TRUE)
)
broom::augment(fit)
broom::glance(fit)
broom::tidy(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.