| correia2019 | R Documentation |
Nonexistence of estimates of Poisson models across different statistical packages.
correia2019
correia2019A list of data frames with three elements:
Data frame used to show lack of convergence
Data frame used to show lack of convergence with step-halving
Data frame with fixed effects used with the 'alpaca' package
'correia2019' GitHub repository (https://github.com/sergiocorreia/correia2019/blob/master/guides/nonexistence_benchmarks.md#r-packages)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.