| fenegbin | R Documentation |
A routine that uses the same internals as feglm.
fenegbin(
formula = NULL,
data = NULL,
weights = NULL,
beta_start = NULL,
eta_start = NULL,
init_theta = NULL,
link = c("log", "identity", "sqrt"),
offset = NULL,
control = NULL
)
formula |
an object of class |
data |
an object of class |
weights |
an optional string with the name of the prior weights variable in |
beta_start |
an optional vector of starting values for the structural parameters in the linear predictor.
Default is |
eta_start |
an optional vector of starting values for the linear predictor. |
init_theta |
an optional initial value for the theta parameter (see glm.nb). |
link |
the link function. Must be one of |
offset |
an optional formula or numeric vector specifying an a priori known component to be included in the
linear predictor. If a formula, it should be of the form |
control |
a named list of parameters for controlling the fitting process. See fit_control for details. |
A named list of class "feglm". The list contains the following
eighteen elements:
coefficients |
a named vector of the estimated coefficients |
eta |
a vector of the linear predictor |
weights |
a vector of the weights used in the estimation |
hessian |
a matrix with the numerical second derivatives |
deviance |
the deviance of the model |
null_deviance |
the null deviance of the model |
conv |
a logical indicating whether the model converged |
iter |
the number of iterations needed to converge |
theta |
the estimated theta parameter |
iter_outer |
the number of outer iterations |
conv_outer |
a logical indicating whether the outer loop converged |
nobs |
a named vector with the number of observations used in the estimation indicating the dropped and perfectly predicted observations |
fe_levels |
a named vector with the number of levels in each fixed effects |
nms_fe |
a list with the names of the fixed effects variables |
formula |
the formula used in the model |
data |
the data used in the model after dropping non-contributing observations |
family |
the family used in the model |
control |
the control list used in the model |
# check the felm examples for the details about clustered standard errors
ross2004_subset <- ross2004[ross2004$year == 1999, ]
ross2004_subset <- ross2004_subset[ross2004_subset$ltrade >
quantile(ross2004_subset$ltrade, 0.75), ]
fit <- fenegbin(ltrade ~ ldist | ctry1, ross2004_subset)
summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.