| fepoisson | R Documentation |
A wrapper for feglm with
family = poisson().
fepoisson(
formula = NULL,
data = NULL,
weights = NULL,
vcov = NULL,
beta_start = NULL,
eta_start = NULL,
offset = NULL,
control = NULL
)
formula |
an object of class |
data |
an object of class |
weights |
an optional string with the name of the prior weights variable in |
vcov |
an optional character string specifying the type of variance-covariance estimator.
One of |
beta_start |
an optional vector of starting values for the structural parameters in the linear predictor.
Default is |
eta_start |
an optional vector of starting values for the linear predictor. |
offset |
an optional formula or numeric vector specifying an a priori known component to be included in the
linear predictor. If a formula, it should be of the form |
control |
a named list of parameters for controlling the fitting process. See fit_control for details. |
A named list of class "feglm".
# check the feglm examples for the details about clustered standard errors
ross2004_subset <- ross2004[ross2004$year == 1999, ]
ross2004_subset <- ross2004_subset[ross2004_subset$ltrade >
quantile(ross2004_subset$ltrade, 0.75), ]
fit <- fepoisson(ltrade ~ ldist, ross2004_subset)
summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.