| ross2004 | R Documentation |
Data from Ross (2004) used to show the different variance-covariance estimators from Cameron and Miller (2014).
ross2004
ross2004A data frame with 234,597 rows and 22 columns:
Log of bilateral trade between i and j at time t
Binary variable which is unity if both i and j are GATT/WTO members at t
Binary variable which is unity if either i or j is a GATT/WTO member at t
Binary variable which is unity if i was a GSP beneficiary of j or vice versa at t
Log of distance between i and j
Log of real GDP
Log of real GDP per capita
Binary variable which is unity if i and j are in the same region
Binary variable which is unity if i and j are in the same customs union
Binary variable which is unity if i and j share a common language
Binary variable which is unity if i and j share a border
Number of landlocked countries in the country-pair (0, 1, or 2)
Number of island nations in the pair (0, 1, or 2)
Log of the area of the country (in square kilometers)
Binary variable which is unity if i and j were ever colonies after 1945 with the same colonizer
Binary variable which is unity if i and j are colonies at time t
Binary variable which is unity if i ever colonized j or vice versa
Binary variable which is unity if i and j remained part of the same nation during the sample (e.g., France and Guadeloupe)
Country 1 ISO-3 code
Country 2 ISO-3 code
Country pair undirected dyads
Year of observation
Do We Really Know That the WTO Increases Trade? (DOI: 10.1257/000282804322970724)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.